DeviceQualificationReport class
Constructors
-
DeviceQualificationReport({required String reportId, required String campaignId, required String deviceName, required String appProfile, required Iterable<
DeviceQualificationPhaseResult> phases, required Iterable<DeviceQualificationFinding> findings, String schemaVersion = '1.0.0'})
Properties
- appProfile → String
-
final
- campaignId → String
-
final
- completeForIssueEvidence → bool
-
no setter
- defectCount → int
-
no setter
- deviceName → String
-
final
- failedCount → int
-
no setter
-
findings
→ List<
DeviceQualificationFinding> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- missingCount → int
-
no setter
- passedCount → int
-
no setter
-
phases
→ List<
DeviceQualificationPhaseResult> -
final
- reportId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → String
-
final
- waivedCount → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMarkdown(
) → String -
toPublicMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited